PLEASE UPDATE README AND DOCS ON ANY UPDATES:
https://mikemike.atlassian.net/wiki/spaces/~61c1f3a7567cb700701985d0/pages/7143426/ai_logstash

# 0.6

    - [WAL-75] Make ai_logstash package public

# 0.5
    - [WAL-50] - add project name to logstash to have not only container/service name

# 0.4
    - moved loggers and error handlers setup into different folders

# 0.2
    - [WAL-38] Divide logger classes for sync and async so it will be harder to do a mess after logger object creation